# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import BackupResourceStorageConfigsNonCRROperations  # type: ignore
from ._operations import BMSPrepareDataMoveOperationResultOperations  # type: ignore
from ._operations import BackupResourceVaultConfigsOperations  # type: ignore
from ._operations import BackupResourceEncryptionConfigsOperations  # type: ignore
from ._operations import ProtectedItemsOperations  # type: ignore
from ._operations import BackupsOperations  # type: ignore
from ._operations import RecoveryPointsRecommendedForMoveOperations  # type: ignore
from ._operations import ProtectedItemOperationStatusesOperations  # type: ignore
from ._operations import ProtectedItemOperationResultsOperations  # type: ignore
from ._operations import ProtectionContainersOperations  # type: ignore
from ._operations import BackupWorkloadItemsOperations  # type: ignore
from ._operations import ProtectionContainerOperationResultsOperations  # type: ignore
from ._operations import RecoveryPointsOperations  # type: ignore
from ._operations import RestoresOperations  # type: ignore
from ._operations import ItemLevelRecoveryConnectionsOperations  # type: ignore
from ._operations import ProtectionPoliciesOperations  # type: ignore
from ._operations import BackupPoliciesOperations  # type: ignore
from ._operations import ProtectionPolicyOperationResultsOperations  # type: ignore
from ._operations import ProtectionPolicyOperationStatusesOperations  # type: ignore
from ._operations import JobDetailsOperations  # type: ignore
from ._operations import BackupJobsOperations  # type: ignore
from ._operations import JobCancellationsOperations  # type: ignore
from ._operations import JobOperationResultsOperations  # type: ignore
from ._operations import ExportJobsOperationResultsOperations  # type: ignore
from ._operations import BackupEnginesOperations  # type: ignore
from ._operations import ResourceGuardProxyOperations  # type: ignore
from ._operations import ResourceGuardProxiesOperations  # type: ignore
from ._operations import BackupStatusOperations  # type: ignore
from ._operations import FeatureSupportOperations  # type: ignore
from ._operations import BackupProtectionIntentOperations  # type: ignore
from ._operations import BackupUsageSummariesOperations  # type: ignore
from ._operations import JobsOperations  # type: ignore
from ._operations import BackupProtectedItemsOperations  # type: ignore
from ._operations import ValidateOperationOperations  # type: ignore
from ._operations import ValidateOperationResultsOperations  # type: ignore
from ._operations import ValidateOperationStatusesOperations  # type: ignore
from ._operations import ProtectionContainerRefreshOperationResultsOperations  # type: ignore
from ._operations import ProtectableContainersOperations  # type: ignore
from ._operations import BackupOperationResultsOperations  # type: ignore
from ._operations import BackupOperationStatusesOperations  # type: ignore
from ._operations import BackupProtectableItemsOperations  # type: ignore
from ._operations import BackupProtectionContainersOperations  # type: ignore
from ._operations import DeletedProtectionContainersOperations  # type: ignore
from ._operations import SecurityPINsOperations  # type: ignore
from ._operations import FetchTieringCostOperations  # type: ignore
from ._operations import GetTieringCostOperationResultOperations  # type: ignore
from ._operations import TieringCostOperationStatusOperations  # type: ignore
from ._operations import ProtectionIntentOperations  # type: ignore
from ._operations import PrivateEndpointConnectionOperations  # type: ignore
from ._operations import PrivateEndpointOperations  # type: ignore
from ._operations import OperationOperations  # type: ignore
from ._operations import _RecoveryServicesBackupClientOperationsMixin  # type: ignore # pylint: disable=unused-import

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "BackupResourceStorageConfigsNonCRROperations",
    "BMSPrepareDataMoveOperationResultOperations",
    "BackupResourceVaultConfigsOperations",
    "BackupResourceEncryptionConfigsOperations",
    "ProtectedItemsOperations",
    "BackupsOperations",
    "RecoveryPointsRecommendedForMoveOperations",
    "ProtectedItemOperationStatusesOperations",
    "ProtectedItemOperationResultsOperations",
    "ProtectionContainersOperations",
    "BackupWorkloadItemsOperations",
    "ProtectionContainerOperationResultsOperations",
    "RecoveryPointsOperations",
    "RestoresOperations",
    "ItemLevelRecoveryConnectionsOperations",
    "ProtectionPoliciesOperations",
    "BackupPoliciesOperations",
    "ProtectionPolicyOperationResultsOperations",
    "ProtectionPolicyOperationStatusesOperations",
    "JobDetailsOperations",
    "BackupJobsOperations",
    "JobCancellationsOperations",
    "JobOperationResultsOperations",
    "ExportJobsOperationResultsOperations",
    "BackupEnginesOperations",
    "ResourceGuardProxyOperations",
    "ResourceGuardProxiesOperations",
    "BackupStatusOperations",
    "FeatureSupportOperations",
    "BackupProtectionIntentOperations",
    "BackupUsageSummariesOperations",
    "JobsOperations",
    "BackupProtectedItemsOperations",
    "ValidateOperationOperations",
    "ValidateOperationResultsOperations",
    "ValidateOperationStatusesOperations",
    "ProtectionContainerRefreshOperationResultsOperations",
    "ProtectableContainersOperations",
    "BackupOperationResultsOperations",
    "BackupOperationStatusesOperations",
    "BackupProtectableItemsOperations",
    "BackupProtectionContainersOperations",
    "DeletedProtectionContainersOperations",
    "SecurityPINsOperations",
    "FetchTieringCostOperations",
    "GetTieringCostOperationResultOperations",
    "TieringCostOperationStatusOperations",
    "ProtectionIntentOperations",
    "PrivateEndpointConnectionOperations",
    "PrivateEndpointOperations",
    "OperationOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, Awaitable, Optional, TYPE_CHECKING, cast
from typing_extensions import Self

from azure.core.pipeline import policies
from azure.core.rest import AsyncHttpResponse, HttpRequest
from azure.core.settings import settings
from azure.mgmt.core import AsyncARMPipelineClient
from azure.mgmt.core.policies import AsyncARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from .._utils.serialization import Deserializer, Serializer
from ._configuration import RecoveryServicesBackupClientConfiguration
from .operations import (
    BMSPrepareDataMoveOperationResultOperations,
    BackupEnginesOperations,
    BackupJobsOperations,
    BackupOperationResultsOperations,
    BackupOperationStatusesOperations,
    BackupPoliciesOperations,
    BackupProtectableItemsOperations,
    BackupProtectedItemsOperations,
    BackupProtectionContainersOperations,
    BackupProtectionIntentOperations,
    BackupResourceEncryptionConfigsOperations,
    BackupResourceStorageConfigsNonCRROperations,
    BackupResourceVaultConfigsOperations,
    BackupStatusOperations,
    BackupUsageSummariesOperations,
    BackupWorkloadItemsOperations,
    BackupsOperations,
    DeletedProtectionContainersOperations,
    ExportJobsOperationResultsOperations,
    FeatureSupportOperations,
    FetchTieringCostOperations,
    GetTieringCostOperationResultOperations,
    ItemLevelRecoveryConnectionsOperations,
    JobCancellationsOperations,
    JobDetailsOperations,
    JobOperationResultsOperations,
    JobsOperations,
    OperationOperations,
    Operations,
    PrivateEndpointConnectionOperations,
    PrivateEndpointOperations,
    ProtectableContainersOperations,
    ProtectedItemOperationResultsOperations,
    ProtectedItemOperationStatusesOperations,
    ProtectedItemsOperations,
    ProtectionContainerOperationResultsOperations,
    ProtectionContainerRefreshOperationResultsOperations,
    ProtectionContainersOperations,
    ProtectionIntentOperations,
    ProtectionPoliciesOperations,
    ProtectionPolicyOperationResultsOperations,
    ProtectionPolicyOperationStatusesOperations,
    RecoveryPointsOperations,
    RecoveryPointsRecommendedForMoveOperations,
    ResourceGuardProxiesOperations,
    ResourceGuardProxyOperations,
    RestoresOperations,
    SecurityPINsOperations,
    TieringCostOperationStatusOperations,
    ValidateOperationOperations,
    ValidateOperationResultsOperations,
    ValidateOperationStatusesOperations,
    _RecoveryServicesBackupClientOperationsMixin,
)

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials_async import AsyncTokenCredential


class RecoveryServicesBackupClient(
    _RecoveryServicesBackupClientOperationsMixin
):  # pylint: disable=too-many-instance-attributes
    """Open API 2.0 Specs for Azure RecoveryServices Backup service.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.recoveryservicesbackup.aio.operations.Operations
    :ivar backup_resource_storage_configs_non_crr: BackupResourceStorageConfigsNonCRROperations
     operations
    :vartype backup_resource_storage_configs_non_crr:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupResourceStorageConfigsNonCRROperations
    :ivar bms_prepare_data_move_operation_result: BMSPrepareDataMoveOperationResultOperations
     operations
    :vartype bms_prepare_data_move_operation_result:
     azure.mgmt.recoveryservicesbackup.aio.operations.BMSPrepareDataMoveOperationResultOperations
    :ivar backup_resource_vault_configs: BackupResourceVaultConfigsOperations operations
    :vartype backup_resource_vault_configs:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupResourceVaultConfigsOperations
    :ivar backup_resource_encryption_configs: BackupResourceEncryptionConfigsOperations operations
    :vartype backup_resource_encryption_configs:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupResourceEncryptionConfigsOperations
    :ivar protected_items: ProtectedItemsOperations operations
    :vartype protected_items:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectedItemsOperations
    :ivar backups: BackupsOperations operations
    :vartype backups: azure.mgmt.recoveryservicesbackup.aio.operations.BackupsOperations
    :ivar recovery_points_recommended_for_move: RecoveryPointsRecommendedForMoveOperations
     operations
    :vartype recovery_points_recommended_for_move:
     azure.mgmt.recoveryservicesbackup.aio.operations.RecoveryPointsRecommendedForMoveOperations
    :ivar protected_item_operation_statuses: ProtectedItemOperationStatusesOperations operations
    :vartype protected_item_operation_statuses:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectedItemOperationStatusesOperations
    :ivar protected_item_operation_results: ProtectedItemOperationResultsOperations operations
    :vartype protected_item_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectedItemOperationResultsOperations
    :ivar protection_containers: ProtectionContainersOperations operations
    :vartype protection_containers:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionContainersOperations
    :ivar backup_workload_items: BackupWorkloadItemsOperations operations
    :vartype backup_workload_items:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupWorkloadItemsOperations
    :ivar protection_container_operation_results: ProtectionContainerOperationResultsOperations
     operations
    :vartype protection_container_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionContainerOperationResultsOperations
    :ivar recovery_points: RecoveryPointsOperations operations
    :vartype recovery_points:
     azure.mgmt.recoveryservicesbackup.aio.operations.RecoveryPointsOperations
    :ivar restores: RestoresOperations operations
    :vartype restores: azure.mgmt.recoveryservicesbackup.aio.operations.RestoresOperations
    :ivar item_level_recovery_connections: ItemLevelRecoveryConnectionsOperations operations
    :vartype item_level_recovery_connections:
     azure.mgmt.recoveryservicesbackup.aio.operations.ItemLevelRecoveryConnectionsOperations
    :ivar protection_policies: ProtectionPoliciesOperations operations
    :vartype protection_policies:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionPoliciesOperations
    :ivar backup_policies: BackupPoliciesOperations operations
    :vartype backup_policies:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupPoliciesOperations
    :ivar protection_policy_operation_results: ProtectionPolicyOperationResultsOperations
     operations
    :vartype protection_policy_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionPolicyOperationResultsOperations
    :ivar protection_policy_operation_statuses: ProtectionPolicyOperationStatusesOperations
     operations
    :vartype protection_policy_operation_statuses:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionPolicyOperationStatusesOperations
    :ivar job_details: JobDetailsOperations operations
    :vartype job_details: azure.mgmt.recoveryservicesbackup.aio.operations.JobDetailsOperations
    :ivar backup_jobs: BackupJobsOperations operations
    :vartype backup_jobs: azure.mgmt.recoveryservicesbackup.aio.operations.BackupJobsOperations
    :ivar job_cancellations: JobCancellationsOperations operations
    :vartype job_cancellations:
     azure.mgmt.recoveryservicesbackup.aio.operations.JobCancellationsOperations
    :ivar job_operation_results: JobOperationResultsOperations operations
    :vartype job_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.JobOperationResultsOperations
    :ivar export_jobs_operation_results: ExportJobsOperationResultsOperations operations
    :vartype export_jobs_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ExportJobsOperationResultsOperations
    :ivar backup_engines: BackupEnginesOperations operations
    :vartype backup_engines:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupEnginesOperations
    :ivar resource_guard_proxy: ResourceGuardProxyOperations operations
    :vartype resource_guard_proxy:
     azure.mgmt.recoveryservicesbackup.aio.operations.ResourceGuardProxyOperations
    :ivar resource_guard_proxies: ResourceGuardProxiesOperations operations
    :vartype resource_guard_proxies:
     azure.mgmt.recoveryservicesbackup.aio.operations.ResourceGuardProxiesOperations
    :ivar backup_status: BackupStatusOperations operations
    :vartype backup_status: azure.mgmt.recoveryservicesbackup.aio.operations.BackupStatusOperations
    :ivar feature_support: FeatureSupportOperations operations
    :vartype feature_support:
     azure.mgmt.recoveryservicesbackup.aio.operations.FeatureSupportOperations
    :ivar backup_protection_intent: BackupProtectionIntentOperations operations
    :vartype backup_protection_intent:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupProtectionIntentOperations
    :ivar backup_usage_summaries: BackupUsageSummariesOperations operations
    :vartype backup_usage_summaries:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupUsageSummariesOperations
    :ivar jobs: JobsOperations operations
    :vartype jobs: azure.mgmt.recoveryservicesbackup.aio.operations.JobsOperations
    :ivar backup_protected_items: BackupProtectedItemsOperations operations
    :vartype backup_protected_items:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupProtectedItemsOperations
    :ivar validate_operation: ValidateOperationOperations operations
    :vartype validate_operation:
     azure.mgmt.recoveryservicesbackup.aio.operations.ValidateOperationOperations
    :ivar validate_operation_results: ValidateOperationResultsOperations operations
    :vartype validate_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ValidateOperationResultsOperations
    :ivar validate_operation_statuses: ValidateOperationStatusesOperations operations
    :vartype validate_operation_statuses:
     azure.mgmt.recoveryservicesbackup.aio.operations.ValidateOperationStatusesOperations
    :ivar protection_container_refresh_operation_results:
     ProtectionContainerRefreshOperationResultsOperations operations
    :vartype protection_container_refresh_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionContainerRefreshOperationResultsOperations
    :ivar protectable_containers: ProtectableContainersOperations operations
    :vartype protectable_containers:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectableContainersOperations
    :ivar backup_operation_results: BackupOperationResultsOperations operations
    :vartype backup_operation_results:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupOperationResultsOperations
    :ivar backup_operation_statuses: BackupOperationStatusesOperations operations
    :vartype backup_operation_statuses:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupOperationStatusesOperations
    :ivar backup_protectable_items: BackupProtectableItemsOperations operations
    :vartype backup_protectable_items:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupProtectableItemsOperations
    :ivar backup_protection_containers: BackupProtectionContainersOperations operations
    :vartype backup_protection_containers:
     azure.mgmt.recoveryservicesbackup.aio.operations.BackupProtectionContainersOperations
    :ivar deleted_protection_containers: DeletedProtectionContainersOperations operations
    :vartype deleted_protection_containers:
     azure.mgmt.recoveryservicesbackup.aio.operations.DeletedProtectionContainersOperations
    :ivar security_pins: SecurityPINsOperations operations
    :vartype security_pins: azure.mgmt.recoveryservicesbackup.aio.operations.SecurityPINsOperations
    :ivar fetch_tiering_cost: FetchTieringCostOperations operations
    :vartype fetch_tiering_cost:
     azure.mgmt.recoveryservicesbackup.aio.operations.FetchTieringCostOperations
    :ivar get_tiering_cost_operation_result: GetTieringCostOperationResultOperations operations
    :vartype get_tiering_cost_operation_result:
     azure.mgmt.recoveryservicesbackup.aio.operations.GetTieringCostOperationResultOperations
    :ivar tiering_cost_operation_status: TieringCostOperationStatusOperations operations
    :vartype tiering_cost_operation_status:
     azure.mgmt.recoveryservicesbackup.aio.operations.TieringCostOperationStatusOperations
    :ivar protection_intent: ProtectionIntentOperations operations
    :vartype protection_intent:
     azure.mgmt.recoveryservicesbackup.aio.operations.ProtectionIntentOperations
    :ivar private_endpoint_connection: PrivateEndpointConnectionOperations operations
    :vartype private_endpoint_connection:
     azure.mgmt.recoveryservicesbackup.aio.operations.PrivateEndpointConnectionOperations
    :ivar private_endpoint: PrivateEndpointOperations operations
    :vartype private_endpoint:
     azure.mgmt.recoveryservicesbackup.aio.operations.PrivateEndpointOperations
    :ivar operation: OperationOperations operations
    :vartype operation: azure.mgmt.recoveryservicesbackup.aio.operations.OperationOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials_async.AsyncTokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword api_version: The API version to use for this operation. Known values are
     "2026-01-31-preview". Default value is "2026-01-31-preview". Note that overriding this default
     value may result in unsupported behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "AsyncTokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = RecoveryServicesBackupClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                AsyncARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: AsyncARMPipelineClient = AsyncARMPipelineClient(
            base_url=cast(str, _endpoint), policies=_policies, **kwargs
        )

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.backup_resource_storage_configs_non_crr = BackupResourceStorageConfigsNonCRROperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.bms_prepare_data_move_operation_result = BMSPrepareDataMoveOperationResultOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_resource_vault_configs = BackupResourceVaultConfigsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_resource_encryption_configs = BackupResourceEncryptionConfigsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protected_items = ProtectedItemsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backups = BackupsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.recovery_points_recommended_for_move = RecoveryPointsRecommendedForMoveOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protected_item_operation_statuses = ProtectedItemOperationStatusesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protected_item_operation_results = ProtectedItemOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_containers = ProtectionContainersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_workload_items = BackupWorkloadItemsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_container_operation_results = ProtectionContainerOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.recovery_points = RecoveryPointsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.restores = RestoresOperations(self._client, self._config, self._serialize, self._deserialize)
        self.item_level_recovery_connections = ItemLevelRecoveryConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_policies = ProtectionPoliciesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_policies = BackupPoliciesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.protection_policy_operation_results = ProtectionPolicyOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_policy_operation_statuses = ProtectionPolicyOperationStatusesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.job_details = JobDetailsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backup_jobs = BackupJobsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.job_cancellations = JobCancellationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.job_operation_results = JobOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.export_jobs_operation_results = ExportJobsOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_engines = BackupEnginesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.resource_guard_proxy = ResourceGuardProxyOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.resource_guard_proxies = ResourceGuardProxiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_status = BackupStatusOperations(self._client, self._config, self._serialize, self._deserialize)
        self.feature_support = FeatureSupportOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backup_protection_intent = BackupProtectionIntentOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_usage_summaries = BackupUsageSummariesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.jobs = JobsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backup_protected_items = BackupProtectedItemsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.validate_operation = ValidateOperationOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.validate_operation_results = ValidateOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.validate_operation_statuses = ValidateOperationStatusesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_container_refresh_operation_results = ProtectionContainerRefreshOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protectable_containers = ProtectableContainersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_operation_results = BackupOperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_operation_statuses = BackupOperationStatusesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_protectable_items = BackupProtectableItemsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backup_protection_containers = BackupProtectionContainersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.deleted_protection_containers = DeletedProtectionContainersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.security_pins = SecurityPINsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.fetch_tiering_cost = FetchTieringCostOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.get_tiering_cost_operation_result = GetTieringCostOperationResultOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.tiering_cost_operation_status = TieringCostOperationStatusOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.protection_intent = ProtectionIntentOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_endpoint_connection = PrivateEndpointConnectionOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_endpoint = PrivateEndpointOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.operation = OperationOperations(self._client, self._config, self._serialize, self._deserialize)

    def send_request(
        self, request: HttpRequest, *, stream: bool = False, **kwargs: Any
    ) -> Awaitable[AsyncHttpResponse]:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = await client.send_request(request)
        <AsyncHttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.AsyncHttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    async def close(self) -> None:
        await self._client.close()

    async def __aenter__(self) -> Self:
        await self._client.__aenter__()
        return self

    async def __aexit__(self, *exc_details: Any) -> None:
        await self._client.__aexit__(*exc_details)



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AcquireStorageAccountLock(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Whether storage account lock is to be acquired for this container or not."""

    ACQUIRE = "Acquire"
    """ACQUIRE."""
    NOT_ACQUIRE = "NotAcquire"
    """NOT_ACQUIRE."""


class AzureFileShareType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """File Share type XSync or XSMB."""

    INVALID = "Invalid"
    """INVALID."""
    XSMB = "XSMB"
    """XSMB."""
    X_SYNC = "XSync"
    """X_SYNC."""


class BackupEngineType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the backup engine."""

    INVALID = "Invalid"
    """INVALID."""
    DPM_BACKUP_ENGINE = "DpmBackupEngine"
    """DPM_BACKUP_ENGINE."""
    AZURE_BACKUP_SERVER_ENGINE = "AzureBackupServerEngine"
    """AZURE_BACKUP_SERVER_ENGINE."""


class BackupItemType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of backup items associated with this container."""

    INVALID = "Invalid"
    """INVALID."""
    VM = "VM"
    """VM."""
    FILE_FOLDER = "FileFolder"
    """FILE_FOLDER."""
    AZURE_SQL_DB = "AzureSqlDb"
    """AZURE_SQL_DB."""
    SQLDB = "SQLDB"
    """SQLDB."""
    EXCHANGE = "Exchange"
    """EXCHANGE."""
    SHAREPOINT = "Sharepoint"
    """SHAREPOINT."""
    V_MWARE_VM = "VMwareVM"
    """V_MWARE_VM."""
    SYSTEM_STATE = "SystemState"
    """SYSTEM_STATE."""
    CLIENT = "Client"
    """CLIENT."""
    GENERIC_DATA_SOURCE = "GenericDataSource"
    """GENERIC_DATA_SOURCE."""
    SQL_DATA_BASE = "SQLDataBase"
    """SQL_DATA_BASE."""
    AZURE_FILE_SHARE = "AzureFileShare"
    """AZURE_FILE_SHARE."""
    SAP_HANA_DATABASE = "SAPHanaDatabase"
    """SAP_HANA_DATABASE."""
    SAP_ASE_DATABASE = "SAPAseDatabase"
    """SAP_ASE_DATABASE."""
    SAP_HANA_DB_INSTANCE = "SAPHanaDBInstance"
    """SAP_HANA_DB_INSTANCE."""


class BackupManagementType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Backup management type to execute the current job."""

    INVALID = "Invalid"
    """INVALID."""
    AZURE_IAAS_VM = "AzureIaasVM"
    """AZURE_IAAS_VM."""
    MAB = "MAB"
    """MAB."""
    DPM = "DPM"
    """DPM."""
    AZURE_BACKUP_SERVER = "AzureBackupServer"
    """AZURE_BACKUP_SERVER."""
    AZURE_SQL = "AzureSql"
    """AZURE_SQL."""
    AZURE_STORAGE = "AzureStorage"
    """AZURE_STORAGE."""
    AZURE_WORKLOAD = "AzureWorkload"
    """AZURE_WORKLOAD."""
    DEFAULT_BACKUP = "DefaultBackup"
    """DEFAULT_BACKUP."""


class BackupType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of backup, viz. Full, Differential, Log or CopyOnlyFull."""

    INVALID = "Invalid"
    """INVALID."""
    FULL = "Full"
    """FULL."""
    DIFFERENTIAL = "Differential"
    """DIFFERENTIAL."""
    LOG = "Log"
    """LOG."""
    COPY_ONLY_FULL = "CopyOnlyFull"
    """COPY_ONLY_FULL."""
    INCREMENTAL = "Incremental"
    """INCREMENTAL."""
    SNAPSHOT_FULL = "SnapshotFull"
    """SNAPSHOT_FULL."""
    SNAPSHOT_COPY_ONLY_FULL = "SnapshotCopyOnlyFull"
    """SNAPSHOT_COPY_ONLY_FULL."""


class CopyOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Options to resolve copy conflicts."""

    INVALID = "Invalid"
    """INVALID."""
    CREATE_COPY = "CreateCopy"
    """CREATE_COPY."""
    SKIP = "Skip"
    """SKIP."""
    OVERWRITE = "Overwrite"
    """OVERWRITE."""
    FAIL_ON_CONFLICT = "FailOnConflict"
    """FAIL_ON_CONFLICT."""


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of entity that created the resource."""

    USER = "User"
    """The entity was created by a user."""
    APPLICATION = "Application"
    """The entity was created by an application."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """The entity was created by a managed identity."""
    KEY = "Key"
    """The entity was created by a key."""


class CreateMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Create mode to indicate recovery of existing soft deleted data source or creation of new data
    source.
    """

    INVALID = "Invalid"
    """INVALID."""
    DEFAULT = "Default"
    """DEFAULT."""
    RECOVER = "Recover"
    """RECOVER."""


class DataMoveLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DataMove Level."""

    INVALID = "Invalid"
    """INVALID."""
    VAULT = "Vault"
    """VAULT."""
    CONTAINER = "Container"
    """CONTAINER."""


class DataSourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of workload this item represents."""

    INVALID = "Invalid"
    """INVALID."""
    VM = "VM"
    """VM."""
    FILE_FOLDER = "FileFolder"
    """FILE_FOLDER."""
    AZURE_SQL_DB = "AzureSqlDb"
    """AZURE_SQL_DB."""
    SQLDB = "SQLDB"
    """SQLDB."""
    EXCHANGE = "Exchange"
    """EXCHANGE."""
    SHAREPOINT = "Sharepoint"
    """SHAREPOINT."""
    V_MWARE_VM = "VMwareVM"
    """V_MWARE_VM."""
    SYSTEM_STATE = "SystemState"
    """SYSTEM_STATE."""
    CLIENT = "Client"
    """CLIENT."""
    GENERIC_DATA_SOURCE = "GenericDataSource"
    """GENERIC_DATA_SOURCE."""
    SQL_DATA_BASE = "SQLDataBase"
    """SQL_DATA_BASE."""
    AZURE_FILE_SHARE = "AzureFileShare"
    """AZURE_FILE_SHARE."""
    SAP_HANA_DATABASE = "SAPHanaDatabase"
    """SAP_HANA_DATABASE."""
    SAP_ASE_DATABASE = "SAPAseDatabase"
    """SAP_ASE_DATABASE."""
    SAP_HANA_DB_INSTANCE = "SAPHanaDBInstance"
    """SAP_HANA_DB_INSTANCE."""


class DayOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of DayOfWeek."""

    SUNDAY = "Sunday"
    """SUNDAY."""
    MONDAY = "Monday"
    """MONDAY."""
    TUESDAY = "Tuesday"
    """TUESDAY."""
    WEDNESDAY = "Wednesday"
    """WEDNESDAY."""
    THURSDAY = "Thursday"
    """THURSDAY."""
    FRIDAY = "Friday"
    """FRIDAY."""
    SATURDAY = "Saturday"
    """SATURDAY."""


class DedupState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Vault Dedup state."""

    INVALID = "Invalid"
    """INVALID."""
    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""


class EncryptionAtRestType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Encryption At Rest Type."""

    INVALID = "Invalid"
    """INVALID."""
    MICROSOFT_MANAGED = "MicrosoftManaged"
    """MICROSOFT_MANAGED."""
    CUSTOMER_MANAGED = "CustomerManaged"
    """CUSTOMER_MANAGED."""


class EnhancedSecurityState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enabled or Disabled."""

    INVALID = "Invalid"
    """INVALID."""
    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""


class FabricName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the fabric name - Azure or AD."""

    INVALID = "Invalid"
    """INVALID."""
    AZURE = "Azure"
    """AZURE."""


class HealthStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Health status of protected item."""

    PASSED = "Passed"
    """PASSED."""
    ACTION_REQUIRED = "ActionRequired"
    """ACTION_REQUIRED."""
    ACTION_SUGGESTED = "ActionSuggested"
    """ACTION_SUGGESTED."""
    INVALID = "Invalid"
    """INVALID."""


class HttpStatusCode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """HTTP Status Code of the operation."""

    CONTINUE_ENUM = "Continue"
    """CONTINUE_ENUM."""
    SWITCHING_PROTOCOLS = "SwitchingProtocols"
    """SWITCHING_PROTOCOLS."""
    OK = "OK"
    """OK."""
    CREATED = "Created"
    """CREATED."""
    ACCEPTED = "Accepted"
    """ACCEPTED."""
    NON_AUTHORITATIVE_INFORMATION = "NonAuthoritativeInformation"
    """NON_AUTHORITATIVE_INFORMATION."""
    NO_CONTENT = "NoContent"
    """NO_CONTENT."""
    RESET_CONTENT = "ResetContent"
    """RESET_CONTENT."""
    PARTIAL_CONTENT = "PartialContent"
    """PARTIAL_CONTENT."""
    MULTIPLE_CHOICES = "MultipleChoices"
    """MULTIPLE_CHOICES."""
    AMBIGUOUS = "Ambiguous"
    """AMBIGUOUS."""
    MOVED_PERMANENTLY = "MovedPermanently"
    """MOVED_PERMANENTLY."""
    MOVED = "Moved"
    """MOVED."""
    FOUND = "Found"
    """FOUND."""
    REDIRECT = "Redirect"
    """REDIRECT."""
    SEE_OTHER = "SeeOther"
    """SEE_OTHER."""
    REDIRECT_METHOD = "RedirectMethod"
    """REDIRECT_METHOD."""
    NOT_MODIFIED = "NotModified"
    """NOT_MODIFIED."""
    USE_PROXY = "UseProxy"
    """USE_PROXY."""
    UNUSED = "Unused"
    """UNUSED."""
    TEMPORARY_REDIRECT = "TemporaryRedirect"
    """TEMPORARY_REDIRECT."""
    REDIRECT_KEEP_VERB = "RedirectKeepVerb"
    """REDIRECT_KEEP_VERB."""
    BAD_REQUEST = "BadRequest"
    """BAD_REQUEST."""
    UNAUTHORIZED = "Unauthorized"
    """UNAUTHORIZED."""
    PAYMENT_REQUIRED = "PaymentRequired"
    """PAYMENT_REQUIRED."""
    FORBIDDEN = "Forbidden"
    """FORBIDDEN."""
    NOT_FOUND = "NotFound"
    """NOT_FOUND."""
    METHOD_NOT_ALLOWED = "MethodNotAllowed"
    """METHOD_NOT_ALLOWED."""
    NOT_ACCEPTABLE = "NotAcceptable"
    """NOT_ACCEPTABLE."""
    PROXY_AUTHENTICATION_REQUIRED = "ProxyAuthenticationRequired"
    """PROXY_AUTHENTICATION_REQUIRED."""
    REQUEST_TIMEOUT = "RequestTimeout"
    """REQUEST_TIMEOUT."""
    CONFLICT = "Conflict"
    """CONFLICT."""
    GONE = "Gone"
    """GONE."""
    LENGTH_REQUIRED = "LengthRequired"
    """LENGTH_REQUIRED."""
    PRECONDITION_FAILED = "PreconditionFailed"
    """PRECONDITION_FAILED."""
    REQUEST_ENTITY_TOO_LARGE = "RequestEntityTooLarge"
    """REQUEST_ENTITY_TOO_LARGE."""
    REQUEST_URI_TOO_LONG = "RequestUriTooLong"
    """REQUEST_URI_TOO_LONG."""
    UNSUPPORTED_MEDIA_TYPE = "UnsupportedMediaType"
    """UNSUPPORTED_MEDIA_TYPE."""
    REQUESTED_RANGE_NOT_SATISFIABLE = "RequestedRangeNotSatisfiable"
    """REQUESTED_RANGE_NOT_SATISFIABLE."""
    EXPECTATION_FAILED = "ExpectationFailed"
    """EXPECTATION_FAILED."""
    UPGRADE_REQUIRED = "UpgradeRequired"
    """UPGRADE_REQUIRED."""
    INTERNAL_SERVER_ERROR = "InternalServerError"
    """INTERNAL_SERVER_ERROR."""
    NOT_IMPLEMENTED = "NotImplemented"
    """NOT_IMPLEMENTED."""
    BAD_GATEWAY = "BadGateway"
    """BAD_GATEWAY."""
    SERVICE_UNAVAILABLE = "ServiceUnavailable"
    """SERVICE_UNAVAILABLE."""
    GATEWAY_TIMEOUT = "GatewayTimeout"
    """GATEWAY_TIMEOUT."""
    HTTP_VERSION_NOT_SUPPORTED = "HttpVersionNotSupported"
    """HTTP_VERSION_NOT_SUPPORTED."""


class IAASVMPolicyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of IAASVMPolicyType."""

    INVALID = "Invalid"
    """INVALID."""
    V1 = "V1"
    """V1."""
    V2 = "V2"
    """V2."""


class IaasVMSnapshotConsistencyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of IaasVMSnapshotConsistencyType."""

    ONLY_CRASH_CONSISTENT = "OnlyCrashConsistent"
    """ONLY_CRASH_CONSISTENT."""


class InfrastructureEncryptionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of InfrastructureEncryptionState."""

    INVALID = "Invalid"
    """INVALID."""
    DISABLED = "Disabled"
    """DISABLED."""
    ENABLED = "Enabled"
    """ENABLED."""


class InquiryStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of protectable item, i.e. InProgress,Succeeded,Failed."""

    INVALID = "Invalid"
    """INVALID."""
    SUCCESS = "Success"
    """SUCCESS."""
    FAILED = "Failed"
    """FAILED."""


class InstanceProtectionReadiness(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The state of instance protection."""

    UNKNOWN = "Unknown"
    """Instance protection readiness is unknown."""
    READY = "Ready"
    """Instance is ready for protection."""
    SCHEDULE_DISABLED = "ScheduleDisabled"
    """Backup schedule is disabled for this instance."""
    PARTIAL_PROTECTION = "PartialProtection"
    """Instance is partially protected."""
    PROTECTION_ERROR = "ProtectionError"
    """Instance protection encountered an error."""


class JobSupportedAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of JobSupportedAction."""

    INVALID = "Invalid"
    """INVALID."""
    CANCELLABLE = "Cancellable"
    """CANCELLABLE."""
    RETRIABLE = "Retriable"
    """RETRIABLE."""


class LastBackupStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Last backup operation status. Possible values: Healthy, Unhealthy."""

    INVALID = "Invalid"
    """INVALID."""
    HEALTHY = "Healthy"
    """HEALTHY."""
    UNHEALTHY = "Unhealthy"
    """UNHEALTHY."""
    IR_PENDING = "IRPending"
    """IR_PENDING."""


class LastUpdateStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of LastUpdateStatus."""

    INVALID = "Invalid"
    """INVALID."""
    NOT_ENABLED = "NotEnabled"
    """NOT_ENABLED."""
    PARTIALLY_SUCCEEDED = "PartiallySucceeded"
    """PARTIALLY_SUCCEEDED."""
    PARTIALLY_FAILED = "PartiallyFailed"
    """PARTIALLY_FAILED."""
    FAILED = "Failed"
    """FAILED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    INITIALIZED = "Initialized"
    """INITIALIZED."""
    FIRST_INITIALIZATION = "FirstInitialization"
    """FIRST_INITIALIZATION."""


class MabServerType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Server type of MAB container."""

    INVALID = "Invalid"
    """INVALID."""
    UNKNOWN = "Unknown"
    """UNKNOWN."""
    IAAS_VM_CONTAINER = "IaasVMContainer"
    """IAAS_VM_CONTAINER."""
    IAAS_VM_SERVICE_CONTAINER = "IaasVMServiceContainer"
    """IAAS_VM_SERVICE_CONTAINER."""
    DPM_CONTAINER = "DPMContainer"
    """DPM_CONTAINER."""
    AZURE_BACKUP_SERVER_CONTAINER = "AzureBackupServerContainer"
    """AZURE_BACKUP_SERVER_CONTAINER."""
    MAB_CONTAINER = "MABContainer"
    """MAB_CONTAINER."""
    CLUSTER = "Cluster"
    """CLUSTER."""
    AZURE_SQL_CONTAINER = "AzureSqlContainer"
    """AZURE_SQL_CONTAINER."""
    WINDOWS = "Windows"
    """WINDOWS."""
    V_CENTER = "VCenter"
    """V_CENTER."""
    VM_APP_CONTAINER = "VMAppContainer"
    """VM_APP_CONTAINER."""
    SQLAG_WORK_LOAD_CONTAINER = "SQLAGWorkLoadContainer"
    """SQLAG_WORK_LOAD_CONTAINER."""
    STORAGE_CONTAINER = "StorageContainer"
    """STORAGE_CONTAINER."""
    GENERIC_CONTAINER = "GenericContainer"
    """GENERIC_CONTAINER."""


class MonthOfYear(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of MonthOfYear."""

    INVALID = "Invalid"
    """INVALID."""
    JANUARY = "January"
    """JANUARY."""
    FEBRUARY = "February"
    """FEBRUARY."""
    MARCH = "March"
    """MARCH."""
    APRIL = "April"
    """APRIL."""
    MAY = "May"
    """MAY."""
    JUNE = "June"
    """JUNE."""
    JULY = "July"
    """JULY."""
    AUGUST = "August"
    """AUGUST."""
    SEPTEMBER = "September"
    """SEPTEMBER."""
    OCTOBER = "October"
    """OCTOBER."""
    NOVEMBER = "November"
    """NOVEMBER."""
    DECEMBER = "December"
    """DECEMBER."""


class OperationStatusValues(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Operation status."""

    INVALID = "Invalid"
    """INVALID."""
    IN_PROGRESS = "InProgress"
    """IN_PROGRESS."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    FAILED = "Failed"
    """FAILED."""
    CANCELED = "Canceled"
    """CANCELED."""


class OperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Re-Do Operation."""

    INVALID = "Invalid"
    """INVALID."""
    REGISTER = "Register"
    """REGISTER."""
    REREGISTER = "Reregister"
    """REREGISTER."""
    REHYDRATE = "Rehydrate"
    """REHYDRATE."""


class OverwriteOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Can Overwrite if Target DataBase already exists."""

    INVALID = "Invalid"
    """INVALID."""
    FAIL_ON_CONFLICT = "FailOnConflict"
    """FAIL_ON_CONFLICT."""
    OVERWRITE = "Overwrite"
    """OVERWRITE."""


class PolicyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of backup policy type."""

    INVALID = "Invalid"
    """INVALID."""
    FULL = "Full"
    """FULL."""
    DIFFERENTIAL = "Differential"
    """DIFFERENTIAL."""
    LOG = "Log"
    """LOG."""
    COPY_ONLY_FULL = "CopyOnlyFull"
    """COPY_ONLY_FULL."""
    INCREMENTAL = "Incremental"
    """INCREMENTAL."""
    SNAPSHOT_FULL = "SnapshotFull"
    """SNAPSHOT_FULL."""
    SNAPSHOT_COPY_ONLY_FULL = "SnapshotCopyOnlyFull"
    """SNAPSHOT_COPY_ONLY_FULL."""


class PrivateEndpointConnectionStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the status."""

    PENDING = "Pending"
    """PENDING."""
    APPROVED = "Approved"
    """APPROVED."""
    REJECTED = "Rejected"
    """REJECTED."""
    DISCONNECTED = "Disconnected"
    """DISCONNECTED."""


class ProtectableContainerType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the container. The value of this property for

    1. Compute Azure VM is Microsoft.Compute/virtualMachines
    2. Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines.
    """

    INVALID = "Invalid"
    """INVALID."""
    UNKNOWN = "Unknown"
    """UNKNOWN."""
    IAAS_VM_CONTAINER = "IaasVMContainer"
    """IAAS_VM_CONTAINER."""
    IAAS_VM_SERVICE_CONTAINER = "IaasVMServiceContainer"
    """IAAS_VM_SERVICE_CONTAINER."""
    DPM_CONTAINER = "DPMContainer"
    """DPM_CONTAINER."""
    AZURE_BACKUP_SERVER_CONTAINER = "AzureBackupServerContainer"
    """AZURE_BACKUP_SERVER_CONTAINER."""
    MAB_CONTAINER = "MABContainer"
    """MAB_CONTAINER."""
    CLUSTER = "Cluster"
    """CLUSTER."""
    AZURE_SQL_CONTAINER = "AzureSqlContainer"
    """AZURE_SQL_CONTAINER."""
    WINDOWS = "Windows"
    """WINDOWS."""
    V_CENTER = "VCenter"
    """V_CENTER."""
    VM_APP_CONTAINER = "VMAppContainer"
    """VM_APP_CONTAINER."""
    SQLAG_WORK_LOAD_CONTAINER = "SQLAGWorkLoadContainer"
    """SQLAG_WORK_LOAD_CONTAINER."""
    STORAGE_CONTAINER = "StorageContainer"
    """STORAGE_CONTAINER."""
    GENERIC_CONTAINER = "GenericContainer"
    """GENERIC_CONTAINER."""
    MICROSOFT_CLASSIC_COMPUTE_VIRTUAL_MACHINES = "Microsoft.ClassicCompute/virtualMachines"
    """MICROSOFT_CLASSIC_COMPUTE_VIRTUAL_MACHINES."""
    MICROSOFT_COMPUTE_VIRTUAL_MACHINES = "Microsoft.Compute/virtualMachines"
    """MICROSOFT_COMPUTE_VIRTUAL_MACHINES."""
    AZURE_WORKLOAD_CONTAINER = "AzureWorkloadContainer"
    """AZURE_WORKLOAD_CONTAINER."""


class ProtectedItemHealthStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Health status of the backup item, evaluated based on last heartbeat received."""

    INVALID = "Invalid"
    """INVALID."""
    HEALTHY = "Healthy"
    """HEALTHY."""
    UNHEALTHY = "Unhealthy"
    """UNHEALTHY."""
    NOT_REACHABLE = "NotReachable"
    """NOT_REACHABLE."""
    IR_PENDING = "IRPending"
    """IR_PENDING."""


class ProtectedItemState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Backup state of the backed up item."""

    INVALID = "Invalid"
    """INVALID."""
    IR_PENDING = "IRPending"
    """IR_PENDING."""
    PROTECTED = "Protected"
    """PROTECTED."""
    PROTECTION_ERROR = "ProtectionError"
    """PROTECTION_ERROR."""
    PROTECTION_STOPPED = "ProtectionStopped"
    """PROTECTION_STOPPED."""
    PROTECTION_PAUSED = "ProtectionPaused"
    """PROTECTION_PAUSED."""
    BACKUPS_SUSPENDED = "BackupsSuspended"
    """BACKUPS_SUSPENDED."""


class ProtectionIntentItemType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """backup protectionIntent type."""

    INVALID = "Invalid"
    """INVALID."""
    AZURE_RESOURCE_ITEM = "AzureResourceItem"
    """AZURE_RESOURCE_ITEM."""
    RECOVERY_SERVICE_VAULT_ITEM = "RecoveryServiceVaultItem"
    """RECOVERY_SERVICE_VAULT_ITEM."""
    AZURE_WORKLOAD_CONTAINER_AUTO_PROTECTION_INTENT = "AzureWorkloadContainerAutoProtectionIntent"
    """AZURE_WORKLOAD_CONTAINER_AUTO_PROTECTION_INTENT."""
    AZURE_WORKLOAD_AUTO_PROTECTION_INTENT = "AzureWorkloadAutoProtectionIntent"
    """AZURE_WORKLOAD_AUTO_PROTECTION_INTENT."""
    AZURE_WORKLOAD_SQL_AUTO_PROTECTION_INTENT = "AzureWorkloadSQLAutoProtectionIntent"
    """AZURE_WORKLOAD_SQL_AUTO_PROTECTION_INTENT."""


class ProtectionLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Protection type in case protected as part of a parent."""

    DATABASE = "Database"
    """Protected at database level."""
    DATABASE_UNDER_INSTANCE = "DatabaseUnderInstance"
    """Database protected under an instance."""


class ProtectionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Backup state of this backup item."""

    INVALID = "Invalid"
    """INVALID."""
    IR_PENDING = "IRPending"
    """IR_PENDING."""
    PROTECTED = "Protected"
    """PROTECTED."""
    PROTECTION_ERROR = "ProtectionError"
    """PROTECTION_ERROR."""
    PROTECTION_STOPPED = "ProtectionStopped"
    """PROTECTION_STOPPED."""
    PROTECTION_PAUSED = "ProtectionPaused"
    """PROTECTION_PAUSED."""
    BACKUPS_SUSPENDED = "BackupsSuspended"
    """BACKUPS_SUSPENDED."""


class ProtectionStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies whether the container is registered or not."""

    INVALID = "Invalid"
    """INVALID."""
    NOT_PROTECTED = "NotProtected"
    """NOT_PROTECTED."""
    PROTECTING = "Protecting"
    """PROTECTING."""
    PROTECTED = "Protected"
    """PROTECTED."""
    PROTECTION_FAILED = "ProtectionFailed"
    """PROTECTION_FAILED."""


class ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets provisioning state of the private endpoint connection."""

    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    DELETING = "Deleting"
    """DELETING."""
    FAILED = "Failed"
    """FAILED."""
    PENDING = "Pending"
    """PENDING."""


class RecoveryMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Defines whether the current recovery mode is file restore or database restore."""

    INVALID = "Invalid"
    """INVALID."""
    FILE_RECOVERY = "FileRecovery"
    """FILE_RECOVERY."""
    WORKLOAD_RECOVERY = "WorkloadRecovery"
    """WORKLOAD_RECOVERY."""
    SNAPSHOT_ATTACH = "SnapshotAttach"
    """SNAPSHOT_ATTACH."""
    RECOVERY_USING_SNAPSHOT = "RecoveryUsingSnapshot"
    """RECOVERY_USING_SNAPSHOT."""
    SNAPSHOT_ATTACH_AND_RECOVER = "SnapshotAttachAndRecover"
    """SNAPSHOT_ATTACH_AND_RECOVER."""


class RecoveryPointTierStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Recovery point tier status."""

    INVALID = "Invalid"
    """INVALID."""
    VALID = "Valid"
    """VALID."""
    DISABLED = "Disabled"
    """DISABLED."""
    DELETED = "Deleted"
    """DELETED."""
    REHYDRATED = "Rehydrated"
    """REHYDRATED."""


class RecoveryPointTierType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Recovery point tier type."""

    INVALID = "Invalid"
    """INVALID."""
    INSTANT_RP = "InstantRP"
    """INSTANT_RP."""
    HARDENED_RP = "HardenedRP"
    """HARDENED_RP."""
    ARCHIVED_RP = "ArchivedRP"
    """ARCHIVED_RP."""


class RecoveryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of this recovery."""

    INVALID = "Invalid"
    """INVALID."""
    ORIGINAL_LOCATION = "OriginalLocation"
    """ORIGINAL_LOCATION."""
    ALTERNATE_LOCATION = "AlternateLocation"
    """ALTERNATE_LOCATION."""
    RESTORE_DISKS = "RestoreDisks"
    """RESTORE_DISKS."""
    OFFLINE = "Offline"
    """OFFLINE."""


class RehydrationPriority(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Rehydration Priority."""

    STANDARD = "Standard"
    """STANDARD."""
    HIGH = "High"
    """HIGH."""


class ResourceHealthStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource Health Status."""

    HEALTHY = "Healthy"
    """HEALTHY."""
    TRANSIENT_DEGRADED = "TransientDegraded"
    """TRANSIENT_DEGRADED."""
    PERSISTENT_DEGRADED = "PersistentDegraded"
    """PERSISTENT_DEGRADED."""
    TRANSIENT_UNHEALTHY = "TransientUnhealthy"
    """TRANSIENT_UNHEALTHY."""
    PERSISTENT_UNHEALTHY = "PersistentUnhealthy"
    """PERSISTENT_UNHEALTHY."""
    INVALID = "Invalid"
    """INVALID."""


class RestorePointType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of restore point."""

    INVALID = "Invalid"
    """INVALID."""
    FULL = "Full"
    """FULL."""
    LOG = "Log"
    """LOG."""
    DIFFERENTIAL = "Differential"
    """DIFFERENTIAL."""
    INCREMENTAL = "Incremental"
    """INCREMENTAL."""
    SNAPSHOT_FULL = "SnapshotFull"
    """SNAPSHOT_FULL."""
    SNAPSHOT_COPY_ONLY_FULL = "SnapshotCopyOnlyFull"
    """SNAPSHOT_COPY_ONLY_FULL."""


class RestoreRequestType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Restore Type (FullShareRestore or ItemLevelRestore)."""

    INVALID = "Invalid"
    """INVALID."""
    FULL_SHARE_RESTORE = "FullShareRestore"
    """FULL_SHARE_RESTORE."""
    ITEM_LEVEL_RESTORE = "ItemLevelRestore"
    """ITEM_LEVEL_RESTORE."""


class RetentionDurationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Retention duration type of retention policy."""

    INVALID = "Invalid"
    """INVALID."""
    DAYS = "Days"
    """DAYS."""
    WEEKS = "Weeks"
    """WEEKS."""
    MONTHS = "Months"
    """MONTHS."""
    YEARS = "Years"
    """YEARS."""


class RetentionScheduleFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Retention schedule format type for monthly retention policy."""

    INVALID = "Invalid"
    """INVALID."""
    DAILY = "Daily"
    """DAILY."""
    WEEKLY = "Weekly"
    """WEEKLY."""


class ScheduleRunType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Frequency of the schedule operation of this policy."""

    INVALID = "Invalid"
    """INVALID."""
    DAILY = "Daily"
    """DAILY."""
    WEEKLY = "Weekly"
    """WEEKLY."""
    HOURLY = "Hourly"
    """HOURLY."""


class SoftDeleteFeatureState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Soft Delete feature state."""

    INVALID = "Invalid"
    """INVALID."""
    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""
    ALWAYS_ON = "AlwaysON"
    """ALWAYS_ON."""


class SourceSideScanStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Threat status of the container."""

    CONFIGURED = "Configured"
    """Source side scan is configured."""
    NOT_CONFIGURED = "NotConfigured"
    """Source side scan is not configured."""
    NOT_APPLICABLE = "NotApplicable"
    """Source side scan is not applicable."""


class SourceSideScanSummary(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Threat summary for the container."""

    UNKNOWN = "Unknown"
    """Scan summary is unknown."""
    NOT_APPLICABLE = "NotApplicable"
    """Scan summary is not applicable."""
    SUSPICIOUS = "Suspicious"
    """Scan summary is suspicious."""
    HEALTHY = "Healthy"
    """Scan summary indicates healthy state."""


class SQLDataDirectoryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of data directory mapping."""

    INVALID = "Invalid"
    """INVALID."""
    DATA = "Data"
    """DATA."""
    LOG = "Log"
    """LOG."""


class StorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Storage type."""

    INVALID = "Invalid"
    """INVALID."""
    GEO_REDUNDANT = "GeoRedundant"
    """GEO_REDUNDANT."""
    LOCALLY_REDUNDANT = "LocallyRedundant"
    """LOCALLY_REDUNDANT."""
    ZONE_REDUNDANT = "ZoneRedundant"
    """ZONE_REDUNDANT."""
    READ_ACCESS_GEO_ZONE_REDUNDANT = "ReadAccessGeoZoneRedundant"
    """READ_ACCESS_GEO_ZONE_REDUNDANT."""


class StorageTypeState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Locked or Unlocked. Once a machine is registered against a resource, the storageTypeState is
    always Locked.
    """

    INVALID = "Invalid"
    """INVALID."""
    LOCKED = "Locked"
    """LOCKED."""
    UNLOCKED = "Unlocked"
    """UNLOCKED."""


class SupportStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Support status of feature."""

    INVALID = "Invalid"
    """INVALID."""
    SUPPORTED = "Supported"
    """SUPPORTED."""
    DEFAULT_OFF = "DefaultOFF"
    """DEFAULT_OFF."""
    DEFAULT_ON = "DefaultON"
    """DEFAULT_ON."""
    NOT_SUPPORTED = "NotSupported"
    """NOT_SUPPORTED."""


class TargetDiskNetworkAccessOption(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Network access settings to be used for restored disks."""

    SAME_AS_ON_SOURCE_DISKS = "SameAsOnSourceDisks"
    """SAME_AS_ON_SOURCE_DISKS."""
    ENABLE_PRIVATE_ACCESS_FOR_ALL_DISKS = "EnablePrivateAccessForAllDisks"
    """ENABLE_PRIVATE_ACCESS_FOR_ALL_DISKS."""
    ENABLE_PUBLIC_ACCESS_FOR_ALL_DISKS = "EnablePublicAccessForAllDisks"
    """ENABLE_PUBLIC_ACCESS_FOR_ALL_DISKS."""


class ThreatSeverity(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Threat Severity Types."""

    CRITICAL = "Critical"
    """Critical severity level."""
    HIGH = "High"
    """High severity level."""
    WARNING = "Warning"
    """Warning severity level."""
    INFORMATIONAL = "Informational"
    """Informational severity level."""


class ThreatState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Threat Status Types."""

    ACTIVE = "Active"
    """Threat is active."""
    IN_PROGRESS = "InProgress"
    """Threat remediation is in progress."""
    IGNORED = "Ignored"
    """Threat has been ignored."""
    RESOLVED = "Resolved"
    """Threat has been resolved."""


class ThreatStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Threat status of the recovery point."""

    UNKNOWN = "Unknown"
    """Threat status is unknown."""
    HEALTHY = "Healthy"
    """Recovery point is healthy."""
    UN_HEALTHY = "UnHealthy"
    """Recovery point is unhealthy."""
    WARNING = "Warning"
    """Recovery point has warning-level threats."""
    NOT_AVAILABLE = "NotAvailable"
    """Threat status is not available."""


class TieringMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Tiering Mode to control automatic tiering of recovery points. Supported values are:

    1. TierRecommended: Tier all recovery points recommended to be tiered
    2. TierAfter: Tier all recovery points after a fixed period, as specified in duration +
    durationType below.
    3. DoNotTier: Do not tier any recovery points.
    """

    INVALID = "Invalid"
    """INVALID."""
    TIER_RECOMMENDED = "TierRecommended"
    """TIER_RECOMMENDED."""
    TIER_AFTER = "TierAfter"
    """TIER_AFTER."""
    DO_NOT_TIER = "DoNotTier"
    """DO_NOT_TIER."""


class UsagesUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Unit of the usage."""

    COUNT = "Count"
    """COUNT."""
    BYTES = "Bytes"
    """BYTES."""
    SECONDS = "Seconds"
    """SECONDS."""
    PERCENT = "Percent"
    """PERCENT."""
    COUNT_PER_SECOND = "CountPerSecond"
    """COUNT_PER_SECOND."""
    BYTES_PER_SECOND = "BytesPerSecond"
    """BYTES_PER_SECOND."""


class ValidationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Validation Status."""

    INVALID = "Invalid"
    """INVALID."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    FAILED = "Failed"
    """FAILED."""


class VaultSubResourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """GroupId for the PrivateEndpointConnection - AzureBackup, AzureBackup_secondary or
    AzureSiteRecovery.
    """

    AZURE_BACKUP = "AzureBackup"
    """AZURE_BACKUP."""
    AZURE_BACKUP_SECONDARY = "AzureBackup_secondary"
    """AZURE_BACKUP_SECONDARY."""
    AZURE_SITE_RECOVERY = "AzureSiteRecovery"
    """AZURE_SITE_RECOVERY."""


class VMWorkloadPolicyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the protection policy."""

    INVALID = "Invalid"
    """Invalid policy type."""
    SNAPSHOT_V1 = "SnapshotV1"
    """Snapshot V1 policy type."""
    SNAPSHOT_V2 = "SnapshotV2"
    """Snapshot V2 policy type."""
    STREAMING = "Streaming"
    """Streaming policy type."""


class WeekOfMonth(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of WeekOfMonth."""

    FIRST = "First"
    """FIRST."""
    SECOND = "Second"
    """SECOND."""
    THIRD = "Third"
    """THIRD."""
    FOURTH = "Fourth"
    """FOURTH."""
    LAST = "Last"
    """LAST."""
    INVALID = "Invalid"
    """INVALID."""


class WorkloadItemType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Workload item type of the item for which intent is to be set."""

    INVALID = "Invalid"
    """INVALID."""
    SQL_INSTANCE = "SQLInstance"
    """SQL_INSTANCE."""
    SQL_DATA_BASE = "SQLDataBase"
    """SQL_DATA_BASE."""
    SAP_HANA_SYSTEM = "SAPHanaSystem"
    """SAP_HANA_SYSTEM."""
    SAP_HANA_DATABASE = "SAPHanaDatabase"
    """SAP_HANA_DATABASE."""
    SAP_ASE_SYSTEM = "SAPAseSystem"
    """SAP_ASE_SYSTEM."""
    SAP_ASE_DATABASE = "SAPAseDatabase"
    """SAP_ASE_DATABASE."""
    SAP_HANA_DB_INSTANCE = "SAPHanaDBInstance"
    """SAP_HANA_DB_INSTANCE."""


class WorkloadType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of workload for the backup management."""

    INVALID = "Invalid"
    """INVALID."""
    VM = "VM"
    """VM."""
    FILE_FOLDER = "FileFolder"
    """FILE_FOLDER."""
    AZURE_SQL_DB = "AzureSqlDb"
    """AZURE_SQL_DB."""
    SQLDB = "SQLDB"
    """SQLDB."""
    EXCHANGE = "Exchange"
    """EXCHANGE."""
    SHAREPOINT = "Sharepoint"
    """SHAREPOINT."""
    V_MWARE_VM = "VMwareVM"
    """V_MWARE_VM."""
    SYSTEM_STATE = "SystemState"
    """SYSTEM_STATE."""
    CLIENT = "Client"
    """CLIENT."""
    GENERIC_DATA_SOURCE = "GenericDataSource"
    """GENERIC_DATA_SOURCE."""
    SQL_DATA_BASE = "SQLDataBase"
    """SQL_DATA_BASE."""
    AZURE_FILE_SHARE = "AzureFileShare"
    """AZURE_FILE_SHARE."""
    SAP_HANA_DATABASE = "SAPHanaDatabase"
    """SAP_HANA_DATABASE."""
    SAP_ASE_DATABASE = "SAPAseDatabase"
    """SAP_ASE_DATABASE."""
    SAP_HANA_DB_INSTANCE = "SAPHanaDBInstance"
    """SAP_HANA_DB_INSTANCE."""


class XcoolState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Vault x-cool state."""

    INVALID = "Invalid"
    """INVALID."""
    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    ArmErrorDetail,
    AzureBackupGoalFeatureSupportRequest,
    AzureBackupServerContainer,
    AzureBackupServerEngine,
    AzureFileShareBackupRequest,
    AzureFileShareProtectableItem,
    AzureFileShareProtectionPolicy,
    AzureFileShareProvisionILRRequest,
    AzureFileShareRecoveryPoint,
    AzureFileShareRestoreRequest,
    AzureFileshareProtectedItem,
    AzureFileshareProtectedItemExtendedInfo,
    AzureIaaSClassicComputeVMContainer,
    AzureIaaSClassicComputeVMProtectableItem,
    AzureIaaSClassicComputeVMProtectedItem,
    AzureIaaSComputeVMContainer,
    AzureIaaSComputeVMProtectableItem,
    AzureIaaSComputeVMProtectedItem,
    AzureIaaSVMErrorInfo,
    AzureIaaSVMHealthDetails,
    AzureIaaSVMJob,
    AzureIaaSVMJobExtendedInfo,
    AzureIaaSVMJobTaskDetails,
    AzureIaaSVMJobV2,
    AzureIaaSVMProtectedItem,
    AzureIaaSVMProtectedItemExtendedInfo,
    AzureIaaSVMProtectionPolicy,
    AzureRecoveryServiceVaultProtectionIntent,
    AzureResourceProtectionIntent,
    AzureSQLAGWorkloadContainerProtectionContainer,
    AzureSqlContainer,
    AzureSqlProtectedItem,
    AzureSqlProtectedItemExtendedInfo,
    AzureSqlProtectionPolicy,
    AzureStorageContainer,
    AzureStorageErrorInfo,
    AzureStorageJob,
    AzureStorageJobExtendedInfo,
    AzureStorageJobTaskDetails,
    AzureStorageProtectableContainer,
    AzureVMAppContainerProtectableContainer,
    AzureVMAppContainerProtectionContainer,
    AzureVMResourceFeatureSupportRequest,
    AzureVMResourceFeatureSupportResponse,
    AzureVmWorkloadItem,
    AzureVmWorkloadProtectableItem,
    AzureVmWorkloadProtectedItem,
    AzureVmWorkloadProtectedItemExtendedInfo,
    AzureVmWorkloadProtectionPolicy,
    AzureVmWorkloadSAPAseDatabaseProtectableItem,
    AzureVmWorkloadSAPAseDatabaseProtectedItem,
    AzureVmWorkloadSAPAseDatabaseWorkloadItem,
    AzureVmWorkloadSAPAseSystemProtectableItem,
    AzureVmWorkloadSAPAseSystemWorkloadItem,
    AzureVmWorkloadSAPHanaDBInstance,
    AzureVmWorkloadSAPHanaDBInstanceProtectedItem,
    AzureVmWorkloadSAPHanaDatabaseProtectableItem,
    AzureVmWorkloadSAPHanaDatabaseProtectedItem,
    AzureVmWorkloadSAPHanaDatabaseWorkloadItem,
    AzureVmWorkloadSAPHanaHSRProtectableItem,
    AzureVmWorkloadSAPHanaScaleoutProtectableItem,
    AzureVmWorkloadSAPHanaSystemProtectableItem,
    AzureVmWorkloadSAPHanaSystemWorkloadItem,
    AzureVmWorkloadSQLAvailabilityGroupProtectableItem,
    AzureVmWorkloadSQLDatabaseProtectableItem,
    AzureVmWorkloadSQLDatabaseProtectedItem,
    AzureVmWorkloadSQLDatabaseWorkloadItem,
    AzureVmWorkloadSQLInstanceProtectableItem,
    AzureVmWorkloadSQLInstanceProtectedItem,
    AzureVmWorkloadSQLInstanceWorkloadItem,
    AzureWorkloadAutoProtectionIntent,
    AzureWorkloadBackupRequest,
    AzureWorkloadContainer,
    AzureWorkloadContainerAutoProtectionIntent,
    AzureWorkloadContainerExtendedInfo,
    AzureWorkloadErrorInfo,
    AzureWorkloadJob,
    AzureWorkloadJobExtendedInfo,
    AzureWorkloadJobTaskDetails,
    AzureWorkloadPointInTimeRecoveryPoint,
    AzureWorkloadPointInTimeRestoreRequest,
    AzureWorkloadRecoveryPoint,
    AzureWorkloadRestoreRequest,
    AzureWorkloadSAPAsePointInTimeRecoveryPoint,
    AzureWorkloadSAPAsePointInTimeRestoreRequest,
    AzureWorkloadSAPAseRecoveryPoint,
    AzureWorkloadSAPAseRestoreRequest,
    AzureWorkloadSAPHanaPointInTimeRecoveryPoint,
    AzureWorkloadSAPHanaPointInTimeRestoreRequest,
    AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest,
    AzureWorkloadSAPHanaRecoveryPoint,
    AzureWorkloadSAPHanaRestoreRequest,
    AzureWorkloadSAPHanaRestoreWithRehydrateRequest,
    AzureWorkloadSQLAutoProtectionIntent,
    AzureWorkloadSQLPointInTimeRecoveryPoint,
    AzureWorkloadSQLPointInTimeRestoreRequest,
    AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest,
    AzureWorkloadSQLRecoveryPoint,
    AzureWorkloadSQLRecoveryPointExtendedInfo,
    AzureWorkloadSQLRestoreRequest,
    AzureWorkloadSQLRestoreWithRehydrateRequest,
    BEKDetails,
    BackupEngineBase,
    BackupEngineBaseResource,
    BackupEngineExtendedInfo,
    BackupManagementUsage,
    BackupRequest,
    BackupRequestResource,
    BackupResourceConfig,
    BackupResourceConfigResource,
    BackupResourceEncryptionConfig,
    BackupResourceEncryptionConfigExtended,
    BackupResourceEncryptionConfigExtendedResource,
    BackupResourceEncryptionConfigResource,
    BackupResourceVaultConfig,
    BackupResourceVaultConfigResource,
    BackupStatusRequest,
    BackupStatusResponse,
    ClientDiscoveryDisplay,
    ClientDiscoveryForLogSpecification,
    ClientDiscoveryForProperties,
    ClientDiscoveryForServiceSpecification,
    ClientDiscoveryValueForSingleApi,
    ClientScriptForConnect,
    ContainerIdentityInfo,
    DPMContainerExtendedInfo,
    DPMProtectedItem,
    DPMProtectedItemExtendedInfo,
    DailyRetentionFormat,
    DailyRetentionSchedule,
    DailySchedule,
    DatabaseInRP,
    Day,
    DiskExclusionProperties,
    DiskInformation,
    DistributedNodesInfo,
    DpmBackupEngine,
    DpmContainer,
    DpmErrorInfo,
    DpmJob,
    DpmJobExtendedInfo,
    DpmJobTaskDetails,
    EncryptionDetails,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    ExportJobsOperationResultInfo,
    ExtendedLocation,
    ExtendedProperties,
    FeatureSupportRequest,
    FetchTieringCostInfoForRehydrationRequest,
    FetchTieringCostInfoRequest,
    FetchTieringCostSavingsInfoForPolicyRequest,
    FetchTieringCostSavingsInfoForProtectedItemRequest,
    FetchTieringCostSavingsInfoForVaultRequest,
    GenericContainer,
    GenericContainerExtendedInfo,
    GenericProtectedItem,
    GenericProtectionPolicy,
    GenericRecoveryPoint,
    HourlySchedule,
    ILRRequest,
    ILRRequestResource,
    IaaSVMContainer,
    IaaSVMProtectableItem,
    IaasVMBackupRequest,
    IaasVMILRRegistrationRequest,
    IaasVMRecoveryPoint,
    IaasVMRestoreRequest,
    IaasVMRestoreWithRehydrationRequest,
    IdentityBasedRestoreDetails,
    IdentityInfo,
    InquiryInfo,
    InquiryValidation,
    InstantItemRecoveryTarget,
    InstantRPAdditionalDetails,
    Job,
    JobResource,
    KEKDetails,
    KPIResourceHealthDetails,
    KeyAndSecretDetails,
    ListRecoveryPointsRecommendedForMoveRequest,
    LogSchedulePolicy,
    LongTermRetentionPolicy,
    LongTermSchedulePolicy,
    MABContainerHealthDetails,
    MabContainer,
    MabContainerExtendedInfo,
    MabErrorInfo,
    MabFileFolderProtectedItem,
    MabFileFolderProtectedItemExtendedInfo,
    MabJob,
    MabJobExtendedInfo,
    MabJobTaskDetails,
    MabProtectionPolicy,
    MonthlyRetentionSchedule,
    MoveRPAcrossTiersRequest,
    NameInfo,
    OperationResultInfo,
    OperationResultInfoBase,
    OperationResultInfoBaseResource,
    OperationStatus,
    OperationStatusError,
    OperationStatusExtendedInfo,
    OperationStatusJobExtendedInfo,
    OperationStatusJobsExtendedInfo,
    OperationStatusProvisionILRExtendedInfo,
    OperationStatusValidateOperationExtendedInfo,
    OperationWorkerResponse,
    PatchRecoveryPointInput,
    PatchRecoveryPointPropertiesInput,
    PointInTimeRange,
    PreBackupValidation,
    PreValidateEnableBackupRequest,
    PreValidateEnableBackupResponse,
    PrepareDataMoveRequest,
    PrepareDataMoveResponse,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionResource,
    PrivateLinkServiceConnectionState,
    ProtectableContainer,
    ProtectableContainerResource,
    ProtectedItem,
    ProtectedItemResource,
    ProtectionContainer,
    ProtectionContainerResource,
    ProtectionIntent,
    ProtectionIntentResource,
    ProtectionPolicy,
    ProtectionPolicyResource,
    ProxyResource,
    RecoveryPoint,
    RecoveryPointDiskConfiguration,
    RecoveryPointMoveReadinessInfo,
    RecoveryPointProperties,
    RecoveryPointRehydrationInfo,
    RecoveryPointResource,
    RecoveryPointTierInformation,
    RecoveryPointTierInformationV2,
    Resource,
    ResourceGuardOperationDetail,
    ResourceGuardProxyBase,
    ResourceGuardProxyBaseResource,
    ResourceHealthDetails,
    ResourceList,
    RestoreFileSpecs,
    RestoreRequest,
    RestoreRequestResource,
    RetentionDuration,
    RetentionPolicy,
    SQLDataDirectory,
    SQLDataDirectoryMapping,
    SchedulePolicy,
    SecuredVMDetails,
    SecurityPinBase,
    Settings,
    SimpleRetentionPolicy,
    SimpleSchedulePolicy,
    SimpleSchedulePolicyV2,
    SnapshotBackupAdditionalDetails,
    SnapshotRestoreParameters,
    SourceSideScanInfo,
    SubProtectionPolicy,
    SystemData,
    TargetAFSRestoreInfo,
    TargetDiskNetworkAccessSettings,
    TargetRestoreInfo,
    ThreatInfo,
    TieringCostInfo,
    TieringCostRehydrationInfo,
    TieringCostSavingInfo,
    TieringPolicy,
    TokenInformation,
    TriggerDataMoveRequest,
    UnlockDeleteRequest,
    UnlockDeleteResponse,
    UpdateRecoveryPointRequest,
    UserAssignedIdentityProperties,
    UserAssignedManagedIdentityDetails,
    ValidateIaasVMRestoreOperationRequest,
    ValidateOperationRequest,
    ValidateOperationRequestResource,
    ValidateOperationResponse,
    ValidateOperationsResponse,
    ValidateRestoreOperationRequest,
    VaultJob,
    VaultJobErrorInfo,
    VaultJobExtendedInfo,
    VaultRetentionPolicy,
    VaultStorageConfigOperationResultResponse,
    WeeklyRetentionFormat,
    WeeklyRetentionSchedule,
    WeeklySchedule,
    WorkloadInquiryDetails,
    WorkloadItem,
    WorkloadItemResource,
    WorkloadProtectableItem,
    WorkloadProtectableItemResource,
    YearlyRetentionSchedule,
)

from ._enums import (  # type: ignore
    AcquireStorageAccountLock,
    AzureFileShareType,
    BackupEngineType,
    BackupItemType,
    BackupManagementType,
    BackupType,
    CopyOptions,
    CreateMode,
    CreatedByType,
    DataMoveLevel,
    DataSourceType,
    DayOfWeek,
    DedupState,
    EncryptionAtRestType,
    EnhancedSecurityState,
    FabricName,
    HealthStatus,
    HttpStatusCode,
    IAASVMPolicyType,
    IaasVMSnapshotConsistencyType,
    InfrastructureEncryptionState,
    InquiryStatus,
    InstanceProtectionReadiness,
    JobSupportedAction,
    LastBackupStatus,
    LastUpdateStatus,
    MabServerType,
    MonthOfYear,
    OperationStatusValues,
    OperationType,
    OverwriteOptions,
    PolicyType,
    PrivateEndpointConnectionStatus,
    ProtectableContainerType,
    ProtectedItemHealthStatus,
    ProtectedItemState,
    ProtectionIntentItemType,
    ProtectionLevel,
    ProtectionState,
    ProtectionStatus,
    ProvisioningState,
    RecoveryMode,
    RecoveryPointTierStatus,
    RecoveryPointTierType,
    RecoveryType,
    RehydrationPriority,
    ResourceHealthStatus,
    RestorePointType,
    RestoreRequestType,
    RetentionDurationType,
    RetentionScheduleFormat,
    SQLDataDirectoryType,
    ScheduleRunType,
    SoftDeleteFeatureState,
    SourceSideScanStatus,
    SourceSideScanSummary,
    StorageType,
    StorageTypeState,
    SupportStatus,
    TargetDiskNetworkAccessOption,
    ThreatSeverity,
    ThreatState,
    ThreatStatus,
    TieringMode,
    UsagesUnit,
    VMWorkloadPolicyType,
    ValidationStatus,
    VaultSubResourceType,
    WeekOfMonth,
    WorkloadItemType,
    WorkloadType,
    XcoolState,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "ArmErrorDetail",
    "AzureBackupGoalFeatureSupportRequest",
    "AzureBackupServerContainer",
    "AzureBackupServerEngine",
    "AzureFileShareBackupRequest",
    "AzureFileShareProtectableItem",
    "AzureFileShareProtectionPolicy",
    "AzureFileShareProvisionILRRequest",
    "AzureFileShareRecoveryPoint",
    "AzureFileShareRestoreRequest",
    "AzureFileshareProtectedItem",
    "AzureFileshareProtectedItemExtendedInfo",
    "AzureIaaSClassicComputeVMContainer",
    "AzureIaaSClassicComputeVMProtectableItem",
    "AzureIaaSClassicComputeVMProtectedItem",
    "AzureIaaSComputeVMContainer",
    "AzureIaaSComputeVMProtectableItem",
    "AzureIaaSComputeVMProtectedItem",
    "AzureIaaSVMErrorInfo",
    "AzureIaaSVMHealthDetails",
    "AzureIaaSVMJob",
    "AzureIaaSVMJobExtendedInfo",
    "AzureIaaSVMJobTaskDetails",
    "AzureIaaSVMJobV2",
    "AzureIaaSVMProtectedItem",
    "AzureIaaSVMProtectedItemExtendedInfo",
    "AzureIaaSVMProtectionPolicy",
    "AzureRecoveryServiceVaultProtectionIntent",
    "AzureResourceProtectionIntent",
    "AzureSQLAGWorkloadContainerProtectionContainer",
    "AzureSqlContainer",
    "AzureSqlProtectedItem",
    "AzureSqlProtectedItemExtendedInfo",
    "AzureSqlProtectionPolicy",
    "AzureStorageContainer",
    "AzureStorageErrorInfo",
    "AzureStorageJob",
    "AzureStorageJobExtendedInfo",
    "AzureStorageJobTaskDetails",
    "AzureStorageProtectableContainer",
    "AzureVMAppContainerProtectableContainer",
    "AzureVMAppContainerProtectionContainer",
    "AzureVMResourceFeatureSupportRequest",
    "AzureVMResourceFeatureSupportResponse",
    "AzureVmWorkloadItem",
    "AzureVmWorkloadProtectableItem",
    "AzureVmWorkloadProtectedItem",
    "AzureVmWorkloadProtectedItemExtendedInfo",
    "AzureVmWorkloadProtectionPolicy",
    "AzureVmWorkloadSAPAseDatabaseProtectableItem",
    "AzureVmWorkloadSAPAseDatabaseProtectedItem",
    "AzureVmWorkloadSAPAseDatabaseWorkloadItem",
    "AzureVmWorkloadSAPAseSystemProtectableItem",
    "AzureVmWorkloadSAPAseSystemWorkloadItem",
    "AzureVmWorkloadSAPHanaDBInstance",
    "AzureVmWorkloadSAPHanaDBInstanceProtectedItem",
    "AzureVmWorkloadSAPHanaDatabaseProtectableItem",
    "AzureVmWorkloadSAPHanaDatabaseProtectedItem",
    "AzureVmWorkloadSAPHanaDatabaseWorkloadItem",
    "AzureVmWorkloadSAPHanaHSRProtectableItem",
    "AzureVmWorkloadSAPHanaScaleoutProtectableItem",
    "AzureVmWorkloadSAPHanaSystemProtectableItem",
    "AzureVmWorkloadSAPHanaSystemWorkloadItem",
    "AzureVmWorkloadSQLAvailabilityGroupProtectableItem",
    "AzureVmWorkloadSQLDatabaseProtectableItem",
    "AzureVmWorkloadSQLDatabaseProtectedItem",
    "AzureVmWorkloadSQLDatabaseWorkloadItem",
    "AzureVmWorkloadSQLInstanceProtectableItem",
    "AzureVmWorkloadSQLInstanceProtectedItem",
    "AzureVmWorkloadSQLInstanceWorkloadItem",
    "AzureWorkloadAutoProtectionIntent",
    "AzureWorkloadBackupRequest",
    "AzureWorkloadContainer",
    "AzureWorkloadContainerAutoProtectionIntent",
    "AzureWorkloadContainerExtendedInfo",
    "AzureWorkloadErrorInfo",
    "AzureWorkloadJob",
    "AzureWorkloadJobExtendedInfo",
    "AzureWorkloadJobTaskDetails",
    "AzureWorkloadPointInTimeRecoveryPoint",
    "AzureWorkloadPointInTimeRestoreRequest",
    "AzureWorkloadRecoveryPoint",
    "AzureWorkloadRestoreRequest",
    "AzureWorkloadSAPAsePointInTimeRecoveryPoint",
    "AzureWorkloadSAPAsePointInTimeRestoreRequest",
    "AzureWorkloadSAPAseRecoveryPoint",
    "AzureWorkloadSAPAseRestoreRequest",
    "AzureWorkloadSAPHanaPointInTimeRecoveryPoint",
    "AzureWorkloadSAPHanaPointInTimeRestoreRequest",
    "AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest",
    "AzureWorkloadSAPHanaRecoveryPoint",
    "AzureWorkloadSAPHanaRestoreRequest",
    "AzureWorkloadSAPHanaRestoreWithRehydrateRequest",
    "AzureWorkloadSQLAutoProtectionIntent",
    "AzureWorkloadSQLPointInTimeRecoveryPoint",
    "AzureWorkloadSQLPointInTimeRestoreRequest",
    "AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest",
    "AzureWorkloadSQLRecoveryPoint",
    "AzureWorkloadSQLRecoveryPointExtendedInfo",
    "AzureWorkloadSQLRestoreRequest",
    "AzureWorkloadSQLRestoreWithRehydrateRequest",
    "BEKDetails",
    "BackupEngineBase",
    "BackupEngineBaseResource",
    "BackupEngineExtendedInfo",
    "BackupManagementUsage",
    "BackupRequest",
    "BackupRequestResource",
    "BackupResourceConfig",
    "BackupResourceConfigResource",
    "BackupResourceEncryptionConfig",
    "BackupResourceEncryptionConfigExtended",
    "BackupResourceEncryptionConfigExtendedResource",
    "BackupResourceEncryptionConfigResource",
    "BackupResourceVaultConfig",
    "BackupResourceVaultConfigResource",
    "BackupStatusRequest",
    "BackupStatusResponse",
    "ClientDiscoveryDisplay",
    "ClientDiscoveryForLogSpecification",
    "ClientDiscoveryForProperties",
    "ClientDiscoveryForServiceSpecification",
    "ClientDiscoveryValueForSingleApi",
    "ClientScriptForConnect",
    "ContainerIdentityInfo",
    "DPMContainerExtendedInfo",
    "DPMProtectedItem",
    "DPMProtectedItemExtendedInfo",
    "DailyRetentionFormat",
    "DailyRetentionSchedule",
    "DailySchedule",
    "DatabaseInRP",
    "Day",
    "DiskExclusionProperties",
    "DiskInformation",
    "DistributedNodesInfo",
    "DpmBackupEngine",
    "DpmContainer",
    "DpmErrorInfo",
    "DpmJob",
    "DpmJobExtendedInfo",
    "DpmJobTaskDetails",
    "EncryptionDetails",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "ExportJobsOperationResultInfo",
    "ExtendedLocation",
    "ExtendedProperties",
    "FeatureSupportRequest",
    "FetchTieringCostInfoForRehydrationRequest",
    "FetchTieringCostInfoRequest",
    "FetchTieringCostSavingsInfoForPolicyRequest",
    "FetchTieringCostSavingsInfoForProtectedItemRequest",
    "FetchTieringCostSavingsInfoForVaultRequest",
    "GenericContainer",
    "GenericContainerExtendedInfo",
    "GenericProtectedItem",
    "GenericProtectionPolicy",
    "GenericRecoveryPoint",
    "HourlySchedule",
    "ILRRequest",
    "ILRRequestResource",
    "IaaSVMContainer",
    "IaaSVMProtectableItem",
    "IaasVMBackupRequest",
    "IaasVMILRRegistrationRequest",
    "IaasVMRecoveryPoint",
    "IaasVMRestoreRequest",
    "IaasVMRestoreWithRehydrationRequest",
    "IdentityBasedRestoreDetails",
    "IdentityInfo",
    "InquiryInfo",
    "InquiryValidation",
    "InstantItemRecoveryTarget",
    "InstantRPAdditionalDetails",
    "Job",
    "JobResource",
    "KEKDetails",
    "KPIResourceHealthDetails",
    "KeyAndSecretDetails",
    "ListRecoveryPointsRecommendedForMoveRequest",
    "LogSchedulePolicy",
    "LongTermRetentionPolicy",
    "LongTermSchedulePolicy",
    "MABContainerHealthDetails",
    "MabContainer",
    "MabContainerExtendedInfo",
    "MabErrorInfo",
    "MabFileFolderProtectedItem",
    "MabFileFolderProtectedItemExtendedInfo",
    "MabJob",
    "MabJobExtendedInfo",
    "MabJobTaskDetails",
    "MabProtectionPolicy",
    "MonthlyRetentionSchedule",
    "MoveRPAcrossTiersRequest",
    "NameInfo",
    "OperationResultInfo",
    "OperationResultInfoBase",
    "OperationResultInfoBaseResource",
    "OperationStatus",
    "OperationStatusError",
    "OperationStatusExtendedInfo",
    "OperationStatusJobExtendedInfo",
    "OperationStatusJobsExtendedInfo",
    "OperationStatusProvisionILRExtendedInfo",
    "OperationStatusValidateOperationExtendedInfo",
    "OperationWorkerResponse",
    "PatchRecoveryPointInput",
    "PatchRecoveryPointPropertiesInput",
    "PointInTimeRange",
    "PreBackupValidation",
    "PreValidateEnableBackupRequest",
    "PreValidateEnableBackupResponse",
    "PrepareDataMoveRequest",
    "PrepareDataMoveResponse",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionResource",
    "PrivateLinkServiceConnectionState",
    "ProtectableContainer",
    "ProtectableContainerResource",
    "ProtectedItem",
    "ProtectedItemResource",
    "ProtectionContainer",
    "ProtectionContainerResource",
    "ProtectionIntent",
    "ProtectionIntentResource",
    "ProtectionPolicy",
    "ProtectionPolicyResource",
    "ProxyResource",
    "RecoveryPoint",
    "RecoveryPointDiskConfiguration",
    "RecoveryPointMoveReadinessInfo",
    "RecoveryPointProperties",
    "RecoveryPointRehydrationInfo",
    "RecoveryPointResource",
    "RecoveryPointTierInformation",
    "RecoveryPointTierInformationV2",
    "Resource",
    "ResourceGuardOperationDetail",
    "ResourceGuardProxyBase",
    "ResourceGuardProxyBaseResource",
    "ResourceHealthDetails",
    "ResourceList",
    "RestoreFileSpecs",
    "RestoreRequest",
    "RestoreRequestResource",
    "RetentionDuration",
    "RetentionPolicy",
    "SQLDataDirectory",
    "SQLDataDirectoryMapping",
    "SchedulePolicy",
    "SecuredVMDetails",
    "SecurityPinBase",
    "Settings",
    "SimpleRetentionPolicy",
    "SimpleSchedulePolicy",
    "SimpleSchedulePolicyV2",
    "SnapshotBackupAdditionalDetails",
    "SnapshotRestoreParameters",
    "SourceSideScanInfo",
    "SubProtectionPolicy",
    "SystemData",
    "TargetAFSRestoreInfo",
    "TargetDiskNetworkAccessSettings",
    "TargetRestoreInfo",
    "ThreatInfo",
    "TieringCostInfo",
    "TieringCostRehydrationInfo",
    "TieringCostSavingInfo",
    "TieringPolicy",
    "TokenInformation",
    "TriggerDataMoveRequest",
    "UnlockDeleteRequest",
    "UnlockDeleteResponse",
    "UpdateRecoveryPointRequest",
    "UserAssignedIdentityProperties",
    "UserAssignedManagedIdentityDetails",
    "ValidateIaasVMRestoreOperationRequest",
    "ValidateOperationRequest",
    "ValidateOperationRequestResource",
    "ValidateOperationResponse",
    "ValidateOperationsResponse",
    "ValidateRestoreOperationRequest",
    "VaultJob",
    "VaultJobErrorInfo",
    "VaultJobExtendedInfo",
    "VaultRetentionPolicy",
    "VaultStorageConfigOperationResultResponse",
    "WeeklyRetentionFormat",
    "WeeklyRetentionSchedule",
    "WeeklySchedule",
    "WorkloadInquiryDetails",
    "WorkloadItem",
    "WorkloadItemResource",
    "WorkloadProtectableItem",
    "WorkloadProtectableItemResource",
    "YearlyRetentionSchedule",
    "AcquireStorageAccountLock",
    "AzureFileShareType",
    "BackupEngineType",
    "BackupItemType",
    "BackupManagementType",
    "BackupType",
    "CopyOptions",
    "CreateMode",
    "CreatedByType",
    "DataMoveLevel",
    "DataSourceType",
    "DayOfWeek",
    "DedupState",
    "EncryptionAtRestType",
    "EnhancedSecurityState",
    "FabricName",
    "HealthStatus",
    "HttpStatusCode",
    "IAASVMPolicyType",
    "IaasVMSnapshotConsistencyType",
    "InfrastructureEncryptionState",
    "InquiryStatus",
    "InstanceProtectionReadiness",
    "JobSupportedAction",
    "LastBackupStatus",
    "LastUpdateStatus",
    "MabServerType",
    "MonthOfYear",
    "OperationStatusValues",
    "OperationType",
    "OverwriteOptions",
    "PolicyType",
    "PrivateEndpointConnectionStatus",
    "ProtectableContainerType",
    "ProtectedItemHealthStatus",
    "ProtectedItemState",
    "ProtectionIntentItemType",
    "ProtectionLevel",
    "ProtectionState",
    "ProtectionStatus",
    "ProvisioningState",
    "RecoveryMode",
    "RecoveryPointTierStatus",
    "RecoveryPointTierType",
    "RecoveryType",
    "RehydrationPriority",
    "ResourceHealthStatus",
    "RestorePointType",
    "RestoreRequestType",
    "RetentionDurationType",
    "RetentionScheduleFormat",
    "SQLDataDirectoryType",
    "ScheduleRunType",
    "SoftDeleteFeatureState",
    "SourceSideScanStatus",
    "SourceSideScanSummary",
    "StorageType",
    "StorageTypeState",
    "SupportStatus",
    "TargetDiskNetworkAccessOption",
    "ThreatSeverity",
    "ThreatState",
    "ThreatStatus",
    "TieringMode",
    "UsagesUnit",
    "VMWorkloadPolicyType",
    "ValidationStatus",
    "VaultSubResourceType",
    "WeekOfMonth",
    "WorkloadItemType",
    "WorkloadType",
    "XcoolState",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
